summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Magefile.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/Magefile.go b/Magefile.go
index 9a82995..f7b79f2 100644
--- a/Magefile.go
+++ b/Magefile.go
@@ -25,9 +25,9 @@ func Build() error {
return sh.RunV("go", "build", "-o", binaryName, "./cmd/player")
}
// Test runs all tests in the project.
func Test() error {
- return sh.RunV("go", "test", "./...")
+ return sh.RunV("go", "test", "-race", "-count=1", "./...")
}
// Install builds and copies the binary to GOPATH/bin.
@@ -25,9 +25,9 @@ func Build() error {
return sh.RunV("go", "build", "-o", binaryName, "./cmd/player")
}
-// Test runs all tests in the project.
+// Test runs all tests in the project with the race detector enabled.
func Test() error {